==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/sqlvirtualmachine/kotlin/inputs/SQLTempDbSettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.sqlvirtualmachine.kotlin.inputs

import com.pulumi.azurenative.sqlvirtualmachine.inputs.SQLTempDbSettingsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property dataFileCount SQL Server tempdb data file count
 * @property dataFileSize SQL Server tempdb data file size
 * @property dataGrowth SQL Server tempdb data file autoGrowth size
 * @property defaultFilePath SQL Server default file path
 * @property logFileSize SQL Server tempdb log file size
 * @property logGrowth SQL Server tempdb log file autoGrowth size
 * @property luns Logical Unit Numbers for the disks.
 * @property persistFolder SQL Server tempdb persist folder choice
 * @property persistFolderPath SQL Server tempdb persist folder location
 */
public data class SQLTempDbSettingsArgs(
    public val dataFileCount: Output<Int>? = null,
    public val dataFileSize: Output<Int>? = null,
    public val dataGrowth: Output<Int>? = null,
    public val defaultFilePath: Output<String>? = null,
    public val logFileSize: Output<Int>? = null,
    public val logGrowth: Output<Int>? = null,
    public val luns: Output<List<Int>>? = null,
    public val persistFolder: Output<Boolean>? = null,
    public val persistFolderPath: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.sqlvirtualmachine.inputs.SQLTempDbSettingsArgs> {
    override fun toJava(): com.pulumi.azurenative.sqlvirtualmachine.inputs.SQLTempDbSettingsArgs =
        com.pulumi.azurenative.sqlvirtualmachine.inputs.SQLTempDbSettingsArgs.builder()
            .dataFileCount(dataFileCount?.applyValue({ args0 -> args0 }))
            .dataFileSize(dataFileSize?.applyValue({ args0 -> args0 }))
            .dataGrowth(dataGrowth?.applyValue({ args0 -> args0 }))
            .defaultFilePath(defaultFilePath?.applyValue({ args0 -> args0 }))
            .logFileSize(logFileSize?.applyValue({ args0 -> args0 }))
            .logGrowth(logGrowth?.applyValue({ args0 -> args0 }))
            .luns(luns?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .persistFolder(persistFolder?.applyValue({ args0 -> args0 }))
            .persistFolderPath(persistFolderPath?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SQLTempDbSettingsArgs].
 */
@PulumiTagMarker
public class SQLTempDbSettingsArgsBuilder internal constructor() {
    private var dataFileCount: Output<Int>? = null

    private var dataFileSize: Output<Int>? = null

    private var dataGrowth: Output<Int>? = null

    private var defaultFilePath: Output<String>? = null

    private var logFileSize: Output<Int>? = null

    private var logGrowth: Output<Int>? = null

    private var luns: Output<List<Int>>? = null

    private var persistFolder: Output<Boolean>? = null

    private var persistFolderPath: Output<String>? = null

    /**
     * @param value SQL Server tempdb data file count
     */
    @JvmName("cpdbtrlxgpasvhfv")
    public suspend fun dataFileCount(`value`: Output<Int>) {
        this.dataFileCount = value
    }

    /**
     * @param value SQL Server tempdb data file size
     */
    @JvmName("dnbwtwpekmrthnwb")
    public suspend fun dataFileSize(`value`: Output<Int>) {
        this.dataFileSize = value
    }

    /**
     * @param value SQL Server tempdb data file autoGrowth size
     */
    @JvmName("younubxymgpbdqof")
    public suspend fun dataGrowth(`value`: Output<Int>) {
        this.dataGrowth = value
    }

    /**
     * @param value SQL Server default file path
     */
    @JvmName("usdogqfdyrnrycvl")
    public suspend fun defaultFilePath(`value`: Output<String>) {
        this.defaultFilePath = value
    }

    /**
     * @param value SQL Server tempdb log file size
     */
    @JvmName("qxdbcjwerxhxldnm")
    public suspend fun logFileSize(`value`: Output<Int>) {
        this.logFileSize = value
    }

    /**
     * @param value SQL Server tempdb log file autoGrowth size
     */
    @JvmName("obdkeoyygurcfeac")
    public suspend fun logGrowth(`value`: Output<Int>) {
        this.logGrowth = value
    }

    /**
     * @param value Logical Unit Numbers for the disks.
     */
    @JvmName("gouschqnngiobrse")
    public suspend fun luns(`value`: Output<List<Int>>) {
        this.luns = value
    }

    @JvmName("dtkuqinsjqujslvb")
    public suspend fun luns(vararg values: Output<Int>) {
        this.luns = Output.all(values.asList())
    }

    /**
     * @param values Logical Unit Numbers for the disks.
     */
    @JvmName("ilngmdehmipreccy")
    public suspend fun luns(values: List<Output<Int>>) {
        this.luns = Output.all(values)
    }

    /**
     * @param value SQL Server tempdb persist folder choice
     */
    @JvmName("qtdwkcijyptkawnw")
    public suspend fun persistFolder(`value`: Output<Boolean>) {
        this.persistFolder = value
    }

    /**
     * @param value SQL Server tempdb persist folder location
     */
    @JvmName("xulxnciyibvscitt")
    public suspend fun persistFolderPath(`value`: Output<String>) {
        this.persistFolderPath = value
    }

    /**
     * @param value SQL Server tempdb data file count
     */
    @JvmName("kiwjrbgwfkarcvie")
    public suspend fun dataFileCount(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dataFileCount = mapped
    }

    /**
     * @param value SQL Server tempdb data file size
     */
    @JvmName("onwmqooemltdijwj")
    public suspend fun dataFileSize(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dataFileSize = mapped
    }

    /**
     * @param value SQL Server tempdb data file autoGrowth size
     */
    @JvmName("qutnurivpnremxqc")
    public suspend fun dataGrowth(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dataGrowth = mapped
    }

    /**
     * @param value SQL Server default file path
     */
    @JvmName("blnapvvdxgpbotjh")
    public suspend fun defaultFilePath(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.defaultFilePath = mapped
    }

    /**
     * @param value SQL Server tempdb log file size
     */
    @JvmName("rjdxoifqqqgkxffq")
    public suspend fun logFileSize(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.logFileSize = mapped
    }

    /**
     * @param value SQL Server tempdb log file autoGrowth size
     */
    @JvmName("wnyxujmnjiapjlhy")
    public suspend fun logGrowth(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.logGrowth = mapped
    }

    /**
     * @param value Logical Unit Numbers for the disks.
     */
    @JvmName("ncyctqjtfeixobmu")
    public suspend fun luns(`value`: List<Int>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.luns = mapped
    }

    /**
     * @param values Logical Unit Numbers for the disks.
     */
    @JvmName("gywrqxqmisecpugs")
    public suspend fun luns(vararg values: Int) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.luns = mapped
    }

    /**
     * @param value SQL Server tempdb persist folder choice
     */
    @JvmName("reprxdbostnptycg")
    public suspend fun persistFolder(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.persistFolder = mapped
    }

    /**
     * @param value SQL Server tempdb persist folder location
     */
    @JvmName("wohjcktloukwqbwk")
    public suspend fun persistFolderPath(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.persistFolderPath = mapped
    }

    internal fun build(): SQLTempDbSettingsArgs = SQLTempDbSettingsArgs(
        dataFileCount = dataFileCount,
        dataFileSize = dataFileSize,
        dataGrowth = dataGrowth,
        defaultFilePath = defaultFilePath,
        logFileSize = logFileSize,
        logGrowth = logGrowth,
        luns = luns,
        persistFolder = persistFolder,
        persistFolderPath = persistFolderPath,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/sqlvirtualmachine/kotlin/inputs/SQLTempDbSettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.sqlvirtualmachine.kotlin.inputs

import com.pulumi.azurenative.sqlvirtualmachine.inputs.SQLTempDbSettingsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property dataFileCount SQL Server tempdb data file count
 * @property dataFileSize SQL Server tempdb data file size
 * @property dataGrowth SQL Server tempdb data file autoGrowth size
 * @property defaultFilePath SQL Server default file path
 * @property logFileSize SQL Server tempdb log file size
 * @property logGrowth SQL Server tempdb log file autoGrowth size
 * @property luns Logical Unit Numbers for the disks.
 * @property persistFolder SQL Server tempdb persist folder choice
 * @property persistFolderPath SQL Server tempdb persist folder location
 */
public data class SQLTempDbSettingsArgs(
    public val dataFileCount: Output<Int>? = null,
    public val dataFileSize: Output<Int>? = null,
    public val dataGrowth: Output<Int>? = null,
    public val defaultFilePath: Output<String>? = null,
    public val logFileSize: Output<Int>? = null,
    public val logGrowth: Output<Int>? = null,
    public val luns: Output<List<Int>>? = null,
    public val persistFolder: Output<Boolean>? = null,
    public val persistFolderPath: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.sqlvirtualmachine.inputs.SQLTempDbSettingsArgs> {
    override fun toJava(): com.pulumi.azurenative.sqlvirtualmachine.inputs.SQLTempDbSettingsArgs =
        com.pulumi.azurenative.sqlvirtualmachine.inputs.SQLTempDbSettingsArgs.builder()
            .dataFileCount(dataFileCount?.applyValue({ args0 -> args0 }))
            .dataFileSize(dataFileSize?.applyValue({ args0 -> args0 }))
            .dataGrowth(dataGrowth?.applyValue({ args0 -> args0 }))
            .defaultFilePath(defaultFilePath?.applyValue({ args0 -> args0 }))
            .logFileSize(logFileSize?.applyValue({ args0 -> args0 }))
            .logGrowth(logGrowth?.applyValue({ args0 -> args0 }))
            .luns(luns?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .persistFolder(persistFolder?.applyValue({ args0 -> args0 }))
            .persistFolderPath(persistFolderPath?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SQLTempDbSettingsArgs].
 */
@PulumiTagMarker
public class SQLTempDbSettingsArgsBuilder internal constructor() {
    private var dataFileCount: Output<Int>? = null

    private var dataFileSize: Output<Int>? = null

    private var dataGrowth: Output<Int>? = null

    private var defaultFilePath: Output<String>? = null

    private var logFileSize: Output<Int>? = null

    private var logGrowth: Output<Int>? = null

    private var luns: Output<List<Int>>? = null

    private var persistFolder: Output<Boolean>? = null

    private var persistFolderPath: Output<String>? = null

    /**
     * @param value SQL Server tempdb data file count
     */
    @JvmName("gbrilhkaagfyhmdq")
    public suspend fun dataFileCount(`value`: Output<Int>) {
        this.dataFileCount = value
    }

    /**
     * @param value SQL Server tempdb data file size
     */
    @JvmName("plcqbqupahnajpbm")
    public suspend fun dataFileSize(`value`: Output<Int>) {
        this.dataFileSize = value
    }

    /**
     * @param value SQL Server tempdb data file autoGrowth size
     */
    @JvmName("bbxjpuqwjaeunecl")
    public suspend fun dataGrowth(`value`: Output<Int>) {
        this.dataGrowth = value
    }

    /**
     * @param value SQL Server default file path
     */
    @JvmName("vkmpmbstfgiogwvu")
    public suspend fun defaultFilePath(`value`: Output<String>) {
        this.defaultFilePath = value
    }

    /**
     * @param value SQL Server tempdb log file size
     */
    @JvmName("nxptvarxrraltjfh")
    public suspend fun logFileSize(`value`: Output<Int>) {
        this.logFileSize = value
    }

    /**
     * @param value SQL Server tempdb log file autoGrowth size
     */
    @JvmName("iqtnypbibceooomf")
    public suspend fun logGrowth(`value`: Output<Int>) {
        this.logGrowth = value
    }

    /**
     * @param value Logical Unit Numbers for the disks.
     */
    @JvmName("omiiyueqftlwjiuj")
    public suspend fun luns(`value`: Output<List<Int>>) {
        this.luns = value
    }

    @JvmName("whckeebxwgjlsonk")
    public suspend fun luns(vararg values: Output<Int>) {
        this.luns = Output.all(values.asList())
    }

    /**
     * @param values Logical Unit Numbers for the disks.
     */
    @JvmName("vxsljocerkvqbrau")
    public suspend fun luns(values: List<Output<Int>>) {
        this.luns = Output.all(values)
    }

    /**
     * @param value SQL Server tempdb persist folder choice
     */
    @JvmName("ggjfapunykbqhgqv")
    public suspend fun persistFolder(`value`: Output<Boolean>) {
        this.persistFolder = value
    }

    /**
     * @param value SQL Server tempdb persist folder location
     */
    @JvmName("lhyhoupkgravortt")
    public suspend fun persistFolderPath(`value`: Output<String>) {
        this.persistFolderPath = value
    }

    /**
     * @param value SQL Server tempdb data file count
     */
    @JvmName("unpvlpuyqqrkjoyu")
    public suspend fun dataFileCount(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dataFileCount = mapped
    }

    /**
     * @param value SQL Server tempdb data file size
     */
    @JvmName("orxssjbpxsqtubql")
    public suspend fun dataFileSize(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dataFileSize = mapped
    }

    /**
     * @param value SQL Server tempdb data file autoGrowth size
     */
    @JvmName("hubviavrycademfp")
    public suspend fun dataGrowth(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dataGrowth = mapped
    }

    /**
     * @param value SQL Server default file path
     */
    @JvmName("atrmhnjiptfedtys")
    public suspend fun defaultFilePath(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.defaultFilePath = mapped
    }

    /**
     * @param value SQL Server tempdb log file size
     */
    @JvmName("gtgmjvhtlngqfikc")
    public suspend fun logFileSize(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.logFileSize = mapped
    }

    /**
     * @param value SQL Server tempdb log file autoGrowth size
     */
    @JvmName("bbcfxbwqwtpvlnww")
    public suspend fun logGrowth(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.logGrowth = mapped
    }

    /**
     * @param value Logical Unit Numbers for the disks.
     */
    @JvmName("donmebcmfvylqvae")
    public suspend fun luns(`value`: List<Int>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.luns = mapped
    }

    /**
     * @param values Logical Unit Numbers for the disks.
     */
    @JvmName("pmpdgtlajqjejcrp")
    public suspend fun luns(vararg values: Int) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.luns = mapped
    }

    /**
     * @param value SQL Server tempdb persist folder choice
     */
    @JvmName("lquemwjxisxbgjtl")
    public suspend fun persistFolder(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.persistFolder = mapped
    }

    /**
     * @param value SQL Server tempdb persist folder location
     */
    @JvmName("flkmpvwyujwkdgwx")
    public suspend fun persistFolderPath(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.persistFolderPath = mapped
    }

    internal fun build(): SQLTempDbSettingsArgs = SQLTempDbSettingsArgs(
        dataFileCount = dataFileCount,
        dataFileSize = dataFileSize,
        dataGrowth = dataGrowth,
        defaultFilePath = defaultFilePath,
        logFileSize = logFileSize,
        logGrowth = logGrowth,
        luns = luns,
        persistFolder = persistFolder,
        persistFolderPath = persistFolderPath,
    )
}
